@@ -238,14 +238,17 @@ class DeveloperProgramResource(APIResource):
             # Check status
             while True:
                 status_ = self.get_project_deployment_status(project_id)
-                print(status['status'])
-                if status['status_code'] == 1:
+                print(status_['status'])
+                if status_['status_code'] == 1:
                     break
                 else:
                     print(f"Checking... ")
                     time.sleep(5)
             return status_
 
+        if 'error_message' in response:
+            raise Exception(response['error_message'])
+
         status = upload(response)
 
         return status
